slepc-3.18.0 2022-10-01
Report Typos and Errors

# RGIsAxisymmetric

Determines if the region is symmetric with respect to the real or imaginary axis.

### Synopsis

    #include "slepcrg.h"
    PetscErrorCode RGIsAxisymmetric(RG rg,PetscBool vertical,PetscBool *symm)

Not Collective

### Input Parameters

| rg | - the region context
| vertical | - true if symmetry must be checked against the vertical axis

### Output Parameter

| symm | - true if the region is axisymmetric

### Note

If the vertical argument is true, symmetry is checked with respect to the vertical axis, otherwise with respect to the horizontal axis.

### See Also

RGCanUseConjugates()

### Level

intermediate

### Location

src/sys/classes/rg/rgbasic.c
Index of all RG routines
Table of Contents for all manual pages
Index of all manual pages